
## CATO-CLI - mutation.admin.removeAdmin:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.admin.removeAdmin) for documentation on this operation.

### Usage for mutation.admin.removeAdmin:

```bash
catocli mutation admin removeAdmin -h

catocli mutation admin removeAdmin <json>

catocli mutation admin removeAdmin --json-file mutation.admin.removeAdmin.json

catocli mutation admin removeAdmin '{"adminID":"id"}'

catocli mutation admin removeAdmin '{
    "adminID": "id"
}'
```

#### Operation Arguments for mutation.admin.removeAdmin ####

`accountId` [ID] - (required) N/A    
`adminID` [ID] - (required) N/A    
